@@ -1,4 +1,6 @@
+from abc import ABC
 from enum import Enum
+from uuid import UUID
 
 from pydantic import BaseModel, ConfigDict
 from pydantic.alias_generators import to_camel
@@ -8,16 +10,18 @@ from timhatdiehandandermaus_sdk.utils import escape_markdown
 # see https://tim-api.bembel.party/docs/swagger/ for api models
 
 
-class ResponseModel(BaseModel):
+class ResponseModel(ABC, BaseModel):
     model_config = ConfigDict(
         alias_generator=to_camel,
         frozen=True,
     )
 
 
-class MovieMetadataFieldEnum(Enum):
-    COVER = "cover"
-    RATING = "rating"
+class RequestModel(ABC, BaseModel):
+    model_config = ConfigDict(
+        populate_by_name=True,
+        alias_generator=to_camel,
+    )
 
 
 class CoverMetadataResponse(ResponseModel):
@@ -91,9 +95,10 @@ class MoviesResponse(ResponseModel):
 
 class QueueItemResponse(ResponseModel):
     id: str
+    user_id: UUID | None
 
 
-class QueueResponse(BaseModel):
+class QueueResponse(ResponseModel):
     queue: list[QueueItemResponse]
 
 
@@ -102,9 +107,17 @@ class MovieDeleteStatusEnum(Enum):
     WATCHED = "Watched"
 
 
-class MoviePostRequest(BaseModel):
-    imdbUrl: str
+class MoviePostRequest(RequestModel):
+    imdb_url: str
+    user_id: UUID | None = None
 
 
-class MovieMetadataPatchRequest(BaseModel):
-    refresh: list[MovieMetadataFieldEnum]
+class CanonicalUserResponse(ResponseModel):
+    id: UUID
+    displayName: str
+
+
+class TelegramUserRequest(RequestModel):
+    id: int
+    first_name: str
+    last_name: str | None
